==> blancoNLpackGenerator-0.0.95-src.zip: src/blanco/nlpack/generator/task/BlancoNLpackGeneratorTranslateXliffByNLpackTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoNLpackGeneratorTranslateXliffByNLpack]̃NX
 */
package blanco.nlpack.generator.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorTranslateXliffByNLpackProcessInput;

/**
 * Apache Ant^XN [BlancoNLpackGeneratorTranslateXliffByNLpack]̃NXB
 *
 * [XLIFFΉc[] pbNg XLIFFt@C(*.xlf)|󂵂܂B̌pbNgĖ|łꍇAXLIFFt@C targetL܂Btargetɑ݂ꍇɂ́Aalt-transɋL܂B( tool-id  target̓eɕωꍇɂ̂݃Zbg܂) ZbgꍇAtarget  state ɂ needs-review-translation Zbg܂B(alt-trans̏ꍇɂ̓Zbg)<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.nlpack.generator.task]BlancoNLpackGeneratorTranslateXliffByNLpackBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blanconlpackgeneratortranslatexliffbynlpack&quot; classname=&quot;blanco.nlpack.generator.task.BlancoNLpackGeneratorTranslateXliffByNLpackTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoNLpackGeneratorTranslateXliffByNLpackTask extends Task {
    /**
     * [XLIFFΉc[] pbNg XLIFFt@C(*.xlf)|󂵂܂B̌pbNgĖ|łꍇAXLIFFt@C targetL܂Btargetɑ݂ꍇɂ́Aalt-transɋL܂B( tool-id  target̓eɕωꍇɂ̂݃Zbg܂) ZbgꍇAtarget  state ɂ needs-review-translation Zbg܂B(alt-trans̏ꍇɂ̓Zbg)
     */
    protected BlancoNLpackGeneratorTranslateXliffByNLpackProcessInput fInput = new BlancoNLpackGeneratorTranslateXliffByNLpackProcessInput();

    /**
     * [XLIFFΉc[] pbNg XLIFFt@C(*.xlf)|󂵂܂B̌pbNgĖ|łꍇAXLIFFt@C targetL܂Btargetɑ݂ꍇɂ́Aalt-transɋL܂B( tool-id  target̓eɕωꍇɂ̂݃Zbg܂) ZbgꍇAtarget  state ɂ needs-review-translation Zbg܂B(alt-trans̏ꍇɂ̓Zbg)
     */
    protected boolean fIsFieldSourcedirProcessed = false;

    /**
     * [XLIFFΉc[] pbNg XLIFFt@C(*.xlf)|󂵂܂B̌pbNgĖ|łꍇAXLIFFt@C targetL܂Btargetɑ݂ꍇɂ́Aalt-transɋL܂B( tool-id  target̓eɕωꍇɂ̂݃Zbg܂) ZbgꍇAtarget  state ɂ needs-review-translation Zbg܂B(alt-trans̏ꍇɂ̓Zbg)
     */
    protected boolean fIsFieldXliffdirProcessed = false;

    /**
     * [XLIFFΉc[] pbNg XLIFFt@C(*.xlf)|󂵂܂B̌pbNgĖ|łꍇAXLIFFt@C targetL܂Btargetɑ݂ꍇɂ́Aalt-transɋL܂B( tool-id  target̓eɕωꍇɂ̂݃Zbg܂) ZbgꍇAtarget  state ɂ needs-review-translation Zbg܂B(alt-trans̏ꍇɂ̓Zbg)
     */
    protected boolean fIsFieldTmpdirProcessed = false;

    /**
     * [XLIFFΉc[] pbNg XLIFFt@C(*.xlf)|󂵂܂B̌pbNgĖ|łꍇAXLIFFt@C targetL܂Btargetɑ݂ꍇɂ́Aalt-transɋL܂B( tool-id  target̓eɕωꍇɂ̂݃Zbg܂) ZbgꍇAtarget  state ɂ needs-review-translation Zbg܂B(alt-trans̏ꍇɂ̓Zbg)
     */
    protected boolean fIsFieldStateProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * pbNi[ꂽ\[XfBNgB*.jart@CWJEclipsevOCB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcedir(final String arg) {
        fInput.setSourcedir(arg);
        fIsFieldSourcedirProcessed = true;
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * pbNi[ꂽ\[XfBNgB*.jart@CWJEclipsevOCB<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcedir() {
        return fInput.getSourcedir();
    }

    /**
     * Ant^XN[xliffdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * XLIFFt@Ci[Ắ^o͐惋[gEtH_w肵܂BXLIFFt@C Bundle-SymbolicName fBNgɊi[邱ƂOƂ܂B<br>
     *
     * @param arg Zbgl
     */
    public void setXliffdir(final String arg) {
        fInput.setXliffdir(arg);
        fIsFieldXliffdirProcessed = true;
    }

    /**
     * Ant^XN[xliffdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * XLIFFt@Ci[Ắ^o͐惋[gEtH_w肵܂BXLIFFt@C Bundle-SymbolicName fBNgɊi[邱ƂOƂ܂B<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getXliffdir() {
        return fInput.getXliffdir();
    }

    /**
     * Ant^XN[tmpdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B<br>
     *
     * @param arg Zbgl
     */
    public void setTmpdir(final String arg) {
        fInput.setTmpdir(arg);
        fIsFieldTmpdirProcessed = true;
    }

    /**
     * Ant^XN[tmpdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B<br>
     * ftHgl[tmp]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTmpdir() {
        return fInput.getTmpdir();
    }

    /**
     * Ant^XN[state]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * target  state ɃZbgeB<br>
     *
     * @param arg Zbgl
     */
    public void setState(final String arg) {
        fInput.setState(arg);
        fIsFieldStateProcessed = true;
    }

    /**
     * Ant^XN[state]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * target  state ɃZbgeB<br>
     *
     * @return ̃tB[h̒l
     */
    public String getState() {
        return fInput.getState();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoNLpackGeneratorTranslateXliffByNLpackTask begin.");

        // ڔԍ[1]AAgr[g[sourcedir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldSourcedirProcessed == false) {
            throw new BuildException("K{Agr[g[sourcedir]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[2]AAgr[g[xliffdir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldXliffdirProcessed == false) {
            throw new BuildException("K{Agr[g[xliffdir]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- sourcedir:[" + getSourcedir() + "]");
            System.out.println("- xliffdir:[" + getXliffdir() + "]");
            System.out.println("- tmpdir:[" + getTmpdir() + "]");
            System.out.println("- state:[" + getState() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoNLpackGeneratorTranslateXliffByNLpackProcessC^tF[X blanco.nlpack.generator.taskpbP[W BlancoNLpackGeneratorTranslateXliffByNLpackProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoNLpackGeneratorTranslateXliffByNLpackProcess proc = new BlancoNLpackGeneratorTranslateXliffByNLpackProcessImpl();
            if (proc.execute(fInput) != BlancoNLpackGeneratorTranslateXliffByNLpackBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}

==> blancoNLpackGenerator-0.1.17-src.zip: src/blanco/nlpack/generator/task/BlancoNLpackGeneratorTranslateXliffByNLpackTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoNLpackGeneratorTranslateXliffByNLpack]̃NX
 */
package blanco.nlpack.generator.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.nlpack.generator.task.valueobject.BlancoNLpackGeneratorTranslateXliffByNLpackProcessInput;

/**
 * Apache Ant^XN [BlancoNLpackGeneratorTranslateXliffByNLpack]̃NXB
 *
 * [XLIFFΉc[] pbNg XLIFFt@C(*.xlf)|󂵂܂B̌pbNgĖ|łꍇAXLIFFt@C targetL܂Btargetɑ݂ꍇɂ́Aalt-transɋL܂B( tool-id  target̓eɕωꍇɂ̂݃Zbg܂) ZbgꍇAtarget  state ɂ needs-review-translation Zbg܂B(alt-trans̏ꍇɂ̓Zbg)<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.nlpack.generator.task]BlancoNLpackGeneratorTranslateXliffByNLpackBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blanconlpackgeneratortranslatexliffbynlpack&quot; classname=&quot;blanco.nlpack.generator.task.BlancoNLpackGeneratorTranslateXliffByNLpackTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoNLpackGeneratorTranslateXliffByNLpackTask extends Task {
    /**
     * [XLIFFΉc[] pbNg XLIFFt@C(*.xlf)|󂵂܂B̌pbNgĖ|łꍇAXLIFFt@C targetL܂Btargetɑ݂ꍇɂ́Aalt-transɋL܂B( tool-id  target̓eɕωꍇɂ̂݃Zbg܂) ZbgꍇAtarget  state ɂ needs-review-translation Zbg܂B(alt-trans̏ꍇɂ̓Zbg)
     */
    protected BlancoNLpackGeneratorTranslateXliffByNLpackProcessInput fInput = new BlancoNLpackGeneratorTranslateXliffByNLpackProcessInput();

    /**
     * tB[h [sourcedir] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldSourcedirProcessed = false;

    /**
     * tB[h [xliffdir] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldXliffdirProcessed = false;

    /**
     * tB[h [tmpdir] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldTmpdirProcessed = false;

    /**
     * tB[h [state] ɒlZbgꂽǂB
     */
    protected boolean fIsFieldStateProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * pbNi[ꂽ\[XfBNgB*.jart@CWJEclipsevOCB<br>
     *
     * @param arg Zbgl
     */
    public void setSourcedir(final String arg) {
        fInput.setSourcedir(arg);
        fIsFieldSourcedirProcessed = true;
    }

    /**
     * Ant^XN[sourcedir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * pbNi[ꂽ\[XfBNgB*.jart@CWJEclipsevOCB<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getSourcedir() {
        return fInput.getSourcedir();
    }

    /**
     * Ant^XN[xliffdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * XLIFFt@Ci[Ắ^o͐惋[gEtH_w肵܂BXLIFFt@C Bundle-SymbolicName fBNgɊi[邱ƂOƂ܂B<br>
     *
     * @param arg Zbgl
     */
    public void setXliffdir(final String arg) {
        fInput.setXliffdir(arg);
        fIsFieldXliffdirProcessed = true;
    }

    /**
     * Ant^XN[xliffdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * XLIFFt@Ci[Ắ^o͐惋[gEtH_w肵܂BXLIFFt@C Bundle-SymbolicName fBNgɊi[邱ƂOƂ܂B<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getXliffdir() {
        return fInput.getXliffdir();
    }

    /**
     * Ant^XN[tmpdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B<br>
     *
     * @param arg Zbgl
     */
    public void setTmpdir(final String arg) {
        fInput.setTmpdir(arg);
        fIsFieldTmpdirProcessed = true;
    }

    /**
     * Ant^XN[tmpdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * e|fBNgw肵܂Bw̏ꍇɂ̓Jgtmpp܂B<br>
     * ftHgl[tmp]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTmpdir() {
        return fInput.getTmpdir();
    }

    /**
     * Ant^XN[state]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * target  state ɃZbgeB<br>
     *
     * @param arg Zbgl
     */
    public void setState(final String arg) {
        fInput.setState(arg);
        fIsFieldStateProcessed = true;
    }

    /**
     * Ant^XN[state]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * target  state ɃZbgeB<br>
     *
     * @return ̃tB[h̒l
     */
    public String getState() {
        return fInput.getState();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    @Override
    public final void execute() throws BuildException {
        System.out.println("BlancoNLpackGeneratorTranslateXliffByNLpackTask begin.");

        // ڔԍ[1]AAgr[g[sourcedir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldSourcedirProcessed == false) {
            throw new BuildException("K{Agr[g[sourcedir]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[2]AAgr[g[xliffdir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldXliffdirProcessed == false) {
            throw new BuildException("K{Agr[g[xliffdir]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- sourcedir:[" + getSourcedir() + "]");
            System.out.println("- xliffdir:[" + getXliffdir() + "]");
            System.out.println("- tmpdir:[" + getTmpdir() + "]");
            System.out.println("- state:[" + getState() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoNLpackGeneratorTranslateXliffByNLpackProcessC^tF[X blanco.nlpack.generator.taskpbP[W BlancoNLpackGeneratorTranslateXliffByNLpackProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoNLpackGeneratorTranslateXliffByNLpackProcess proc = new BlancoNLpackGeneratorTranslateXliffByNLpackProcessImpl();
            if (proc.execute(fInput) != BlancoNLpackGeneratorTranslateXliffByNLpackBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}
